import {Component, OnInit} from '@angular/core';
import {ApiService} from '../../services/api.service';
import {UtilsService} from '../../services/utils.service';
import {Event} from '../../models/event';

@Component({
	selector: 'app-admin',
	templateUrl: './admin.component.html',
	styleUrls: ['./admin.component.css']
})
export class AdminComponent implements OnInit {

	isLoggedIn: boolean = false;
	events: Event[] = [];
	selectedCalendar: string = '';
	password: string = '';
	name: string = '';
	eventFilter: string = 'all';
	eventSorting: string = 'start_asc';

	constructor(
		private api: ApiService
	) {
	}

	ngOnInit(): void {
		if (UtilsService.getPasswordFromLocalStorage() !== '') {
			this.isLoggedIn = true;
			this.getEvents();
		}
	}

	getEvents(): void {
		this.events = [];

		if (this.selectedCalendar === '') {
			return;
		}

		this.api.getEvents(this.selectedCalendar).subscribe((events: Event[]): void => {
			for (let event of events) {
				this.events.push({
					...event,
					startDateTime: new Date(event.startDateTime),
					endDateTime: new Date(event.endDateTime),
					createdDate: new Date(event.createdDate)
				});
			}
			this.filterEvents();
			this.sortEvents();
		});
	}

	login(): void {
		UtilsService.saveUserInfoToLocalStorage(this.password, this.name);
		this.isLoggedIn = true;
		this.getEvents();
	}

	handleCalendarChange() {
		this.getEvents();
	}

	getCalendarId(text: string): number {
		switch (text) {
			case 'public':
				return 1;
			case 'members':
				return 2;
			case 'management':
				return 3;
			default:
				return -1;
		}
	}

	filterEvents() {
		this.events = this.events.filter((event) => {
			return this.checkEventMeetsFilterCriteria(event);
		});
	}

	checkEventMeetsFilterCriteria(event: Event): boolean {
		switch (this.eventFilter) {
			case '':
				return true;
			case 'all':
				return true;
			case 'future':
				return this.reduceToDay(new Date(event.endDateTime)) >= this.reduceToDay(new Date());
			case 'past':
				return this.reduceToDay(new Date(event.endDateTime)) < this.reduceToDay(new Date());
			default:
				return true;
		}
	}

	reduceToDay(date: Date): Date {
		let dayOnlyDate: Date = new Date();
		dayOnlyDate.setFullYear(date.getFullYear());
		dayOnlyDate.setMonth(date.getMonth());
		dayOnlyDate.setDate(date.getDate());

		return dayOnlyDate;
	}

	getUserName(): string {
		return UtilsService.getNameFromLocalStorage();
	}

	sortEvents(): void {
		this.events.sort((a, b) => {
			switch (this.eventSorting) {
				case '':
					return 1;
				case 'start_asc':
					return a.startDateTime > b.startDateTime ? 1 : -1;
				case 'start_desc':
					return a.startDateTime > b.startDateTime ? -1 : 1;
				case 'created_asc':
					return a.createdDate > b.createdDate ? 1 : -1;
				case 'created_desc':
					return a.createdDate > b.createdDate ? -1 : 1;
				default:
					return 1;
			}
			return 1;
		});
	}
}
